#ifndef SMART_TOOLS_SCRIPT_FILE_H
#define SMART_TOOLS_SCRIPT_FILE_H

/*!
	\brief This class represents script when it's exists on local file system as regular file.
	
	StScriptFile allows you to execute a script like you would in a shell. It does not
	load file and you cannot edit it in memory and then execute. This possibly gives you
	StScript class.
	
	\sa StScript and StApplication
*/

#include "stfile.h"
#include "smarttools.h"
#include "ststringlist.h"
#include "stapplication.h"

class StScriptFile : public StApplication 
{
	public:
		StScriptFile(){ setShell(ST_DEFAULT_SHELL); }
		StScriptFile( const StFile& script, const StFile& shell=ST_DEFAULT_SHELL ) { setScript(script); setShell(shell); }
		
		/*! This can be for example /bin/bash for bash scripts or /usr/bin/php for php scripts. When set, file can not exist. */
		bool setShell( const StFile& shell ) { return StApplication::setExecutable( shell ); }
		
		/*! Point to script file to execute. When set, file can not exist. */
		void setScript( const StFile& script ) { scriptFile = script; }
		
		/*! Set arguments to execute with script. */
		void setArguments( const StStringList& args ) { this->args = args; }
		/*! Overloaded version of function above. But add argument as one, not multiple. */
		void setArguments( const StString& arg ) { setArguments( StStringList() << arg ); }
		
		/*!
			Execute the script.
			\param wait - stop execution while executing the script? If no, you can always check hasFinished()
			\param outputToFile if true, application output will be saved to file without displaying it
		*/
		bool execute( bool wait=true, bool outputToFile=true ){ StApplication::setArguments( StStringList() << scriptFile << args ); return StApplication::execute(wait, outputToFile); }

		/*! Get the current script StFile */
		StFile getScript() const { return scriptFile; }
		
	protected:
		StStringList args;
		
	private:
		StFile scriptFile;
		
		/// Disallow of use this function couse of possible missunderstand
		bool setExecutable( const StFile& file ){ return true; };
};

#endif //SMART_TOOLS_SCRIPT_FILE_H

